@@ -2,8 +2,13 @@
 
 PACKAGE=$(dpkg-parsechangelog -S Source)
 VERSION=$2
-DIR=${PACKAGE}-${VERSION}
-TAR=../${PACKAGE}_${VERSION}.orig.tar.xz
+
+if [ "$VERSION" = "" ] ; then
+      VERSION=`dpkg-parsechangelog | awk '/^Version:/ { print $2 }' | sed 's/\([0-9\.]\+\)+[dfsg0-9.]\+-[0-9]\+$/\1/'`
+fi
+
+DIR=${PACKAGE}-${VERSION}+dfg
+TAR=../${PACKAGE}_${VERSION}+dfsg.orig.tar.xz
 
 svn export http://svn.svnkit.com/repos/3rdparty/de.regnis.q.sequence/tags/$VERSION $DIR
 tar -c -J -f $TAR \
